@@ -30,5 +30,5 @@ from .api import terrorist_tweets_classification_pieChart
 from .api import distribution_sentiment_terrorist_tweets
 from .api import close_duplicates
 from .api import duplicates_detection
-from .api import community_algortihm
-from .api import graph_json_values
\ No newline at end of file
+from .api import graph_json_values
+from .api import graph_algoritm_selected
\ No newline at end of file
