@@ -52,8 +52,10 @@ nltk.download('punkt')
 
 #----------------------------------------FUNCTIONS-----------------------------------------------------------------------------#
 
-def load_file(filename):
-    df = pd.read_json(filename)
+def load_file(json_filename):
+
+    data = json.load(json_filename)
+    df = pd.DataFrame(data["results"])
     return df
 
 def merge_dataframes(df1, df2):
@@ -373,11 +375,12 @@ def graph_json_values(df_graph, df_algComu):
       
     data['edges'] = []
     for i in range(len(df_graph)):
-        data['edges'].append({
-          'screen_name': df_graph["screen_name"].iloc[i],
-          'screen_name_mention': df_graph["screen_name_mention"].iloc[i],
-          'iteration': str(df_graph["iteration"].iloc[i])
-        })
+        if(df_graph["screen_name_mention"].iloc[i] != "Empty"):        
+            data['edges'].append({
+              'screen_name': df_graph["screen_name"].iloc[i],
+              'screen_name_mention': df_graph["screen_name_mention"].iloc[i],
+              'iteration': str(df_graph["iteration"].iloc[i])
+            })
       
     return json.dumps(data)
     
@@ -933,44 +936,47 @@ def close_duplicates(data):
     return data
 	
 def text_to_list_features_conversor (data):
-	for index, row in data.iterrows():
-		data["text_tweets_days_list"].iloc[index] = data.loc[index,"text_tweets_days_list"].replace('"', "'").replace("], [","?#??").strip("[]'").split("?#??")
-		list_day = []                                                                                
-		list_text_tweets_day = []
-		list_tweet_date_days = []
-		list_RT_days = []
-		list_lang_days = []
-		text_days = data.loc[index,"tw_day_list"].strip("][").replace(")", ")??").split("??, ")
-		tweet_date_days = data.loc[index,"tweet_date_days_list"].replace("], [","???").split("???")
-		RT_days = data.loc[index, "RT_days_list"].strip("[]").split("], [")
-		lang_days = data.loc[index, "lang_days_list"].strip("[]").split("], [")
-		for i in range(len(text_days)):
-			tweet_date_day = tweet_date_days[i].replace("), ",")??").strip("[]").split("??")
-			text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace('"', "'").replace("¿¿??##%', '","¿¿??##%").strip("[]'").split("¿¿??##%")[:-1]
-			RT_day = list(ast.literal_eval(str(RT_days[i])))
-			if len(lang_days[i])<6:
-				lang_day = [lang_days[i]]
-			else:
-				lang_day = list(ast.literal_eval(lang_days[i]))
-			list_tweet_date_day = []
-			for j in range(len(tweet_date_day)):                
-				if(tweet_date_day == ["'Empty'"]):
-					list_tweet_date_day.append("Empty")
-				else:
-					list_tweet_date_day.append(datetime.strptime(tweet_date_day[j],"Timestamp('%Y-%m-%d %H:%M:%S%z', tz='UTC')"))    
-			if i == len(text_days)-1:
-				text_days[i] = text_days[i].replace("??","")
-			list_day.append(datetime.strptime(text_days[i],'datetime.date(%Y, %m, %d)' ).date())
-			list_text_tweets_day.append(text_tweets_day)
-			list_tweet_date_days.append(list_tweet_date_day)
-			list_RT_days.append(RT_day)
-			list_lang_days.append(lang_day)
-		data["text_tweets_days_list"].iloc[index] = list_text_tweets_day
-		data["tw_day_list"].iloc[index]= list_day
-		data["tweet_date_days_list"].iloc[index]= list_tweet_date_days
-		data["RT_days_list"].iloc[index] = list_RT_days
-		data["lang_days_list"].iloc[index] = list_lang_days
-	return data
+    for index, row in data.iterrows():
+        data["favorite_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index, "favorite_tweets_list"])
+        data["retweet_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index,"retweet_tweets_list"])
+        data["tw_per_day_list"].iloc[index] = ast.literal_eval(data.loc[index,"tw_per_day_list"])
+        data["text_tweets_days_list"].iloc[index] = data.loc[index,"text_tweets_days_list"].replace('"', "'").replace("], [","?#??").strip("[]'").split("?#??")
+        list_day = []                                                                                
+        list_text_tweets_day = []
+        list_tweet_date_days = []
+        list_RT_days = []
+        list_lang_days = []
+        text_days = data.loc[index,"tw_day_list"].strip("][").replace(")", ")??").split("??, ")
+        tweet_date_days = data.loc[index,"tweet_date_days_list"].replace("], [","???").split("???")
+        RT_days = data.loc[index, "RT_days_list"].strip("[]").split("], [")
+        lang_days = data.loc[index, "lang_days_list"].strip("[]").split("], [")
+        for i in range(len(text_days)):
+            tweet_date_day = tweet_date_days[i].replace("), ",")??").strip("[]").split("??")
+            text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace('"', "'").replace("¿¿??##%', '","¿¿??##%").strip("[]'").split("¿¿??##%")[:-1]
+            RT_day = list(ast.literal_eval(str(RT_days[i])))
+            if len(lang_days[i])<6:
+                lang_day = [lang_days[i]]
+            else:
+                lang_day = list(ast.literal_eval(lang_days[i]))
+            list_tweet_date_day = []
+            for j in range(len(tweet_date_day)):                
+                if(tweet_date_day == ["'Empty'"]):
+                    list_tweet_date_day.append("Empty")
+                else:
+                    list_tweet_date_day.append(datetime.strptime(tweet_date_day[j],"Timestamp('%Y-%m-%d %H:%M:%S%z', tz='UTC')"))    
+            if i == len(text_days)-1:
+                text_days[i] = text_days[i].replace("??","")
+            list_day.append(datetime.strptime(text_days[i],'datetime.date(%Y, %m, %d)' ).date())
+            list_text_tweets_day.append(text_tweets_day)
+            list_tweet_date_days.append(list_tweet_date_day)
+            list_RT_days.append(RT_day)
+            list_lang_days.append(lang_day)
+        data["text_tweets_days_list"].iloc[index] = list_text_tweets_day
+        data["tw_day_list"].iloc[index]= list_day
+        data["tweet_date_days_list"].iloc[index]= list_tweet_date_days
+        data["RT_days_list"].iloc[index] = list_RT_days
+        data["lang_days_list"].iloc[index] = list_lang_days
+    return data
 	
 
 #----------------------------------------------Filters-------------------------------------------------------#
@@ -1081,16 +1087,9 @@ def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessT
         df_evaluate = df_evaluate.append(df_metadata_moreData, ignore_index=True)
     return df_evaluate
 
-def contextual_analysis_profile(data, keyword_corpus, hashtag_corpus):  
-    #To remember which name of the tw_per_day_list belongs each tweets
-    print(tw_per_day_list)
-    print("AAAAAAAAAAAAAA")
-    print(data["lang_days_list"])
+def contextual_analysis_profile(data, keyword_corpus, hashtag_corpus):
     n_list_tw = range(0, len(data["tw_per_day_list"]))
-    print(n_list_tw)
-    print(len(data["text_tweets_days_list"]))
-    print(len(data["RT_days_list"]))
-    print(len(data["lang_days_list"]))
+    #To remember which name of the tw_per_day_list belongs each tweets
     aux = pd.DataFrame({'text':data["text_tweets_days_list"],'RT':data["RT_days_list"],'lang': data["lang_days_list"], 'n_list_tw':n_list_tw})
     tweets_df = pd.DataFrame()
     for i in range(len(aux)):
@@ -1102,7 +1101,7 @@ def contextual_analysis_profile(data, keyword_corpus, hashtag_corpus):
     tweets_df = keyword_score(tweets_df, sample_data_tokenized,keyword_corpus)
     tweets_df = hashtag_score(tweets_df,hashtag_corpus)	
     tweets_df["terrorist_suggestion"] = 0
-    tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0.3)] = 1
+    tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0)] = 1
     tweets_irr_words = len(tweets_df[tweets_df["terrorist_suggestion"]==1])
     if len(tweets_df[tweets_df["terrorist_suggestion"]==1]) == 0:
       data["per_hash_key"] = 0
@@ -1326,7 +1325,7 @@ def keyword_score(data,sample_data_tokenized, keyword_corpus):
 
 
 def terrorist_keywords_belonging(data):
-	temp = data[data['keyword_score']>0.3].reset_index(drop=True)
+	temp = data[data['keyword_score']>0].reset_index(drop=True)
 	# Draw plot
 	fig, ax = plt.subplots(figsize=(36,8), dpi= 80)
 	ax.vlines(x=temp.index, ymin=0, ymax=temp.keyword_score, color='firebrick', alpha=0.7, linewidth=2)
